@@ -6,7 +6,7 @@ from python_search.apps.clipboard import Clipboard
 
 class CollectInput:
     """
-    Ask the user for input and return the entered _entries
+    GUI window to capture user input and returns the entered data. It also allows the user to prefill the input field with content from their clipboard.
     """
 
     def launch(
@@ -14,6 +14,7 @@ class CollectInput:
         name="Enter Data",
         default_content="",
         prefill_with_clipboard: bool = False,
+        set_as_clipboard: bool = False,
     ):
         """
         Launch the _entries capture GUI.
@@ -67,7 +68,10 @@ class CollectInput:
                     sys.exit(1)
 
             window.close()
-        return values["content"]
+        result = values["content"]
+        if set_as_clipboard:
+            Clipboard().set_content(result)
+        return result
 
 
 def main():
