@@ -1,13 +1,24 @@
 import os
 
 
-class ChatGPT:
+from python_search.error.exception import notify_exception
+
+SUPPORTED_MODELS = [
+    "gpt-3.5-turbo",
+    "gpt-4",
+    "text-davinci-003",
+    "curie:ft-jean-personal-2023-03-20-21-40-47",
+]
+
+
+class LLMPrompt:
     """
     Uses OpenAI to answer a given prompt.
     """
 
-    def __init__(self, max_tokens=500):
+    MODEL_ENGINE = "text-davinci-003"
 
+    def __init__(self, max_tokens=500):
         self.max_tokens = int(max_tokens)
 
     def collect_prompt_via_ui(self):
@@ -54,26 +65,36 @@ Prompt:
 
         print(result)
 
-    def answer(self, prompt: str, debug=False):
+    @notify_exception()
+    def answer(self, prompt: str, debug=False, max_tokens=500, model=None) -> str:
         """
         Answer a prompt with openAI results
         """
         if len(prompt) > 4097:
             prompt = prompt[:4097]
+        self.max_tokens = int(max_tokens)
+
+        if model == "gpt-3.5-turbo":
+            return ChatGPTAPI().prompt(prompt)
 
         import openai
 
         openai.api_key = os.environ["OPENAI_KEY"]
-        model_engine = "text-davinci-003"
         # Set the maximum number of tokens to generate in the response
 
         if debug:
             print("Prompt: ", prompt)
 
-        # Generate a response
+        engine = self.MODEL_ENGINE
+        if model is not None:
+            engine = None
+
         try:
+            # print("Open AI Key used: ", openai.api_key)
+            # Generate a response
             completion = openai.Completion.create(
-                engine=model_engine,
+                model=model,
+                engine=engine,
                 prompt=prompt,
                 max_tokens=self.max_tokens,
                 temperature=0.5,
@@ -81,21 +102,52 @@ Prompt:
                 frequency_penalty=0,
                 presence_penalty=0,
             )
-        except Exception as e:
-            print(f"Error {e}")
+            return completion.choices[0].text.strip()
+        except openai.error.RateLimitError as e:
+            print(str(e))
+            from python_search.apps.notification_ui import send_notification
+
+            send_notification(str(e))
             return ""
+        return ""
 
         # Print the response
-        return completion.choices[0].text.strip()
 
     def print_answer(self, prompt):
         print(self.answer(prompt))
 
 
+class ChatGPTAPI:
+    def prompt(self, text) -> str:
+        import openai
+
+        openai.api_key = os.environ["OPENAI_KEY"]
+        # print("Open AI Key used: ", openai.api_key)
+
+        try:
+            result = openai.ChatCompletion.create(
+                model="gpt-3.5-turbo",
+                messages=[
+                    {"role": "system", "content": "You are a helpful assistant"},
+                    {"role": "user", "content": text},
+                ],
+            )
+            return result.choices[0].message.content
+
+        except openai.error.RateLimitError as e:
+            print(str(e))
+            from python_search.apps.notification_ui import send_notification
+
+            send_notification(str(e))
+            return ""
+
+        return ""
+
+
 def main():
     import fire
 
-    fire.Fire(ChatGPT)
+    fire.Fire()
 
 
 if __name__ == "__main__":
