@@ -1,4 +1,5 @@
 import datetime
+import os
 from typing import Optional, List, Tuple, Literal
 
 from python_search.entries_group import EntriesGroup
@@ -6,9 +7,10 @@ from python_search.features import PythonSearchFeaturesSupport
 from python_search.theme import TimeBasedThemeSelector
 
 
+
 class PythonSearchConfiguration(EntriesGroup):
     """
-    The main _configuration of Python Search
+    The main configuration of Python Search
     Everything to customize about the application is configurable via code through this class
     """
 
@@ -20,32 +22,41 @@ class PythonSearchConfiguration(EntriesGroup):
     tags_dependent_inserter_marks = None
     _initialization_time = None
     _default_text_editor = "vim"
-    _default_fzf_theme = None
+    _fzf_theme = None
     use_webservice = False
+    rerank_via_model = False
+    entry_generation = False
+    privacy_sensitive_terms = None
 
     def __init__(
         self,
         *,
         entries: Optional[dict] = None,
         entries_groups: Optional[List[EntriesGroup]] = None,
-        supported_features: Optional[PythonSearchFeaturesSupport] = None,
         default_tags=None,
         tags_dependent_inserter_marks: Optional[dict[str, Tuple[str, str]]] = None,
         default_text_editor: Optional[str] = None,
-        default_fzf_theme: Optional[Literal["light", "dark"]] = None,
+        fzf_theme: Literal[
+            "light", "dark", "dracula", "default", "automatic"
+        ] = "automatic",
         custom_window_size: Optional[Tuple[int, int]] = None,
-        use_webservice=False
+        use_webservice=False,
+        rerank_via_model=False,
+        collect_data: bool = False,
+        entry_generation=False,
+        privacy_sensitive_terms: Optional[List[str]] = None,
     ):
         """
 
         :param entries:
         :param entries_groups:
-        :param supported_features:
         :param default_tags:
         :param tags_dependent_inserter_marks:
         :param default_text_editor:
-        :param default_fzf_theme: the theme to use for fzf
+        :param fzf_theme: the theme to use for fzf
         :param custom_window_size: the size of the fzf window
+        :param use_webservice: if True, the ranking will be generated via a webservice
+        :param collect_data: if True, we will collect data about the entries you run in your machine
         """
         if entries:
             self.commands = entries
@@ -53,29 +64,31 @@ class PythonSearchConfiguration(EntriesGroup):
         if entries_groups:
             self.aggregate_commands(entries_groups)
 
-        if supported_features:
-            self.supported_features: PythonSearchFeaturesSupport = supported_features
-        else:
-            self.supported_features: PythonSearchFeaturesSupport = (
-                PythonSearchFeaturesSupport.default()
-            )
+        self.supported_features: PythonSearchFeaturesSupport = (
+            PythonSearchFeaturesSupport.default()
+        )
 
         if default_tags:
             self._default_tags = default_tags
 
         self.tags_dependent_inserter_marks = tags_dependent_inserter_marks
 
+        self.rerank_via_model = rerank_via_model
+
         self._initialization_time = datetime.datetime.now()
         self._default_text_editor = default_text_editor
-        self._default_fzf_theme = (
-            default_fzf_theme
-            if default_fzf_theme
+        self._fzf_theme = (
+            fzf_theme
+            if fzf_theme != "automatic"
             else TimeBasedThemeSelector().get_theme()
         )
         if custom_window_size:
             self._custom_window_size = custom_window_size
 
         self.use_webservice = use_webservice
+        self.collect_data = collect_data
+        self.entry_generation = entry_generation
+        self.privacy_sensitive_terms = privacy_sensitive_terms
 
     def get_next_item_predictor_model(self):
         """
@@ -83,7 +96,6 @@ class PythonSearchConfiguration(EntriesGroup):
 
         :return:
         """
-        # version = 'v1'
         version = "v2"
 
         if version == "v1":
@@ -99,14 +111,28 @@ class PythonSearchConfiguration(EntriesGroup):
 
             return NextItemBaseModelV2()
 
+    def is_on_change_rank_enabled(self):
+        """
+        Enables the behaviour of ranking fzf on any type and given chat-gpt completions around it
+        """
+        return False
+
     def get_text_editor(self):
         return self._default_text_editor
 
+    def is_rerank_via_model_enabled(self):
+        home = os.path.expanduser("~")
+        if os.path.exists(f"{home}/.python_search/feature_enable_next_item_predictor"):
+            # print("rerank_via_model is enabled")
+            return True
+
+        return self.rerank_via_model
+
     def get_default_tags(self):
         return self._default_tags
 
     def get_fzf_theme(self):
-        return self._default_fzf_theme
+        return self._fzf_theme
 
     def get_window_size(self):
         if hasattr(self, "_custom_window_size"):
