@@ -1,35 +1,31 @@
 from python_search.configuration.loader import ConfigurationLoader
-from python_search.data_ui.entries_page import extract_value_from_entry
-
+from python_search.core_entities.core_entities import Entry
 
 class DataExporter:
-    blacklisted_terms = [
-        "http://",
-        "https://",
-        "email",
-        "no key ",
-        "insurance",
-        "token",
-        "private",
-        "endereco",
-        "password",
-        "secret",
-        "passport",
-        "passaporte",
-        "telefone",
-        "phone",
-        "celular",
-        "cellphone",
-        "cpf",
-    ]
 
-    def export_as_text(self):
+    MAX_LENGTH = 100
 
-        entries = ConfigurationLoader().load_entries()
+    def __init__(self):
+        import os
 
-        data = ""
+        extra_excluded_terms = os.environ.get("PYTHON_SEARCH_EXCLUDE_EXPORT", "")
+        if extra_excluded_terms:
+            print("Adding extra excluded terms: ", extra_excluded_terms)
+            self.blacklisted_terms.extend(extra_excluded_terms.split(" "))
+
+    def filter_out_blacklisted(self, entries):
+        result = {}
         for key, value in entries.items():
-            serializeable_value = extract_value_from_entry(value).replace("\n", " ")
+            entry = Entry(key, value)
+            content = entry.get_content_str()
+            serializeable_value = content.replace("\n", " ")
+
+            if serializeable_value.strip() == "":
+                continue
+
+            if len(serializeable_value) > self.MAX_LENGTH:
+                continue
+
             if any(
                 [
                     blackelisted_entry in key.lower()
@@ -51,7 +47,19 @@ class DataExporter:
             if "private" in value:
                 continue
 
-            data = data + f"{key}={serializeable_value}\n"
+            result[key] = serializeable_value
+
+        return result
+
+    def export_as_text(self):
+        entries = ConfigurationLoader().load_entries()
+
+        data = ""
+        entries = self.filter_out_blacklisted(entries)
+        for key, value in entries.items():
+            entry = Entry(key, value)
+            content = entry.get_content_str()
+            data = data + f"{key}={content}\n"
 
         with open("exported_entries.txt", "w") as f:
             f.write(data)
