@@ -15,6 +15,8 @@ class Preview:
     Preview the entry in the search ui
     """
 
+    entries = None
+
     def __init__(self):
         self.configuration = ConfigurationLoader()
         self.logger = setup_preview_logger()
@@ -26,60 +28,51 @@ class Preview:
         Prints the entry in the preview window
 
         """
+        entry_data = None
         key = self._extract_key(entry_text)
         if not self._key_exists(key):
-            print(f"Not found as key {entry_text}")
+            print("Key not found")
+            print(entry_text)
             return
 
-        data = self._build_values_to_print(entry_text)
+        entry_data = self._load_key_data(key)
+        data = self._build_values_to_print(entry_text, key, entry_data)
         self._print_values(data)
 
     def _print_values(self, data):
         print("")
-        print(
-            data["type"]
-            + ": "
-            + self._color_str(data["value"], self._get_color_for_type(data["type"]))
-        )
-        print(f"Key: {self._color_str(data['key'], Fore.YELLOW)}")
+        print(f"{data['key']}")
+
+        if "value" in data:
+            print("")
+            print(
+                f'{self._color_str(data["value"], self._get_color_for_type(data["type"]))}'
+            )
+        print("")
+
+        print(f"Type: {data['type']}")
         if "description" in data:
             print(f"Description: {data['description']}")
 
         if "created_at" in data:
-            print("Created at: " + data["created_at"])
-            print("Entry Age: " + data["entry_age"])
+            print("Created at: " + data["created_at"].split(".")[0])
 
         if "tags" in data:
             print(f"Tags: {data['tags']}")
         if "position" in data:
             print("Position: " + data["position"])
 
-        if "uuid" in data:
-            print("Uuid: " + data["uuid"][0:8])
-
     def _get_color_for_type(self, type):
-        if type == "Cmd":
-            return Fore.RED
-
-        if type in ["Url", "File"]:
-            return Fore.GREEN
-
-        return Fore.BLUE
+        return Fore.GREEN
 
     def _extract_key(self, entry_text):
-        key = entry_text.split(":")[0]
-        # remove the last 2 spaces from the key as they are used for formatting the string in fzf
-        key = key.strip()
-        return key
+        return entry_text.split(":")[0].strip()
 
-    def _build_values_to_print(self, entry_text) -> dict:
+    def _build_values_to_print(self, entry_text, key, entry_data) -> dict:
         # the entry content is after the key + a ":" character
-        key = self._extract_key(entry_text)
-
         result = {}
         result["type"] = "Unknown"
         result["key"] = key
-        entry_data = self._load_key_data(key)
         if "url" in entry_data:
             result["value"] = entry_data.get("url")
             result["type"] = "Url"
@@ -103,7 +96,6 @@ class Preview:
             result["value"] = dill.source.getsource(value)
 
         if "created_at" in entry_data:
-
             creation_date = parser.parse(entry_data["created_at"])
             today = datetime.now()
             result["created_at"] = str(creation_date)
@@ -134,8 +126,11 @@ class Preview:
     def _color_str(self, a_string, a_color) -> str:
         return f"{a_color}{a_string}{Fore.RESET}"
 
-    def _key_exists(self, key):
-        return key in self.entries
+    def _key_exists(self, key_proposed):
+        if key_proposed in self.entries:
+            return True
+
+        return False
 
     def _load_key_data(self, key):
         if not self._key_exists(key):
