@@ -1,16 +1,12 @@
 from fastapi import FastAPI
 from fastapi.responses import PlainTextResponse
 
-from python_search.entry_description_generator.description_geneartor import (
-    DescriptionGenerator,
-    EntryKeyGeneratorCmd,
-)
 from python_search.entry_type.classifier_inference import (
     EntryData,
     PredictEntryTypeInference,
 )
 from python_search.events.latest_used_entries import RecentKeys
-from python_search.events.run_performed import RunPerformed
+from python_search.events.run_performed import EntryExecuted
 from python_search.events.run_performed.writer import RunPerformedWriter
 from python_search.configuration.loader import ConfigurationLoader
 from python_search.search.search import Search
@@ -29,7 +25,6 @@ app = FastAPI()
 search = Search(ConfigurationLoader().load_config())
 results = search.search()
 entry_type_inference = PredictEntryTypeInference()
-description_generator = DescriptionGenerator()
 
 
 def reload_ranking():
@@ -41,7 +36,6 @@ def reload_ranking():
 
 @app.get("/ranking/generate", response_class=PlainTextResponse)
 def generate_ranking(skip_model: bool = False, base_rank=False, get_latest=True):
-
     global results
     if get_latest and not base_rank:
         return results
@@ -76,8 +70,7 @@ def health():
 
 
 @app.post("/log_run")
-def log_run(event: RunPerformed):
-
+def log_run(event: EntryExecuted):
     RecentKeys.add_latest_used(event.key)
     RunPerformedWriter().write(event)
     # regenerate the search after running a key
@@ -92,12 +85,6 @@ def predict_entry_type_endpoint(entry: EntryData):
     return {"predicted_type": type, "prediction_uuid": uuid}
 
 
-@app.post("/entry/generate_description")
-def generate_description(entry: EntryKeyGeneratorCmd):
-    with pyroscope.tag_wrapper({"endpoint": "generate_description"}):
-        result = description_generator.generate(entry)
-        return {"generated_description": result}
-
 
 @app.get("/recent_history")
 def recent_history_endpoint():
@@ -105,7 +92,6 @@ def recent_history_endpoint():
 
 
 def main():
-
     import os
 
     import uvicorn
